==> linuxconf-1.19.src.tar.gz: linuxconf-1.19/modules/redhatppp/wvdial.cc <==
#include "redhatppp.h"
#include "redhatppp.m"
#include "../../paths.h"
#include <confdb.h>

extern HELP_FILE help_ptp;


static CONFIG_FILE f_wvdial (ETC_WVDIAL_CONF
	,help_ptp
	,CONFIGF_MANAGED|CONFIGF_OPTIONAL
	,"root","root",0600,subsys_dialout);

/*
	Return true if /etc/wvdial.conf exists
*/
bool wvdial_is_installed()
{
	return f_wvdial.exist();
}

static const char STUPIDMODE[]="Stupide Mode";

/*
	Update /etc/wvdial.conf
*/
void wvdial_update (
	const char *config,
	const char *login,
	const char *passwd,
	const char *phone,
	const char *modemport,
	const char *linespeed,
	bool stupidmode)
{
	/* #Specification: /etc/wvdial.conf / conditionnal updates
		The redhatppp module only update the /etc/wvdial.conf if it
		exist.
	*/
	if (f_wvdial.exist()){
		CONFDB conf (f_wvdial,true,';');
		SSTRING subsys;
		subsys.setfromf("Dialer %s",config);
		conf.setcursys (subsys.get(),true);
		conf.replacek ("Modem",modemport);
		conf.replacek ("Baud",linespeed);
		conf.replacek ("Phone",phone);
		conf.replacek ("Username",login);
		conf.replacek ("Password",passwd);
		conf.replacek (STUPIDMODE,stupidmode ? "1" : "0");
		conf.save();
	}
}

/*
	Return the stupidmode setting as stored in wvdial.conf
*/
bool wvdial_getstupidmode(const char *config)
{
	bool ret = false;
	if (f_wvdial.exist()){
		CONFDB conf (f_wvdial,true,';');
		SSTRING subsys;
		subsys.setfromf("Dialer %s",config);
		conf.setcursys (subsys.get(),true);
		const char *val = conf.getvalk (STUPIDMODE,"0");
		if (strcmp(val,"1")==0
			|| strcmp(val,"true")==0) ret = true;
	}
	return ret;
}

==> linuxconf-1.21.src.tar.gz: linuxconf-1.21/modules/redhatppp/wvdial.cc <==
#include "redhatppp.h"
#include "redhatppp.m"
#include "../../paths.h"
#include <confdb.h>

extern HELP_FILE help_ptp;


static CONFIG_FILE f_wvdial (ETC_WVDIAL_CONF
	,help_ptp
	,CONFIGF_MANAGED|CONFIGF_OPTIONAL
	,"root","root",0600,subsys_dialout);

/*
	Return true if /etc/wvdial.conf exists
*/
bool wvdial_is_installed()
{
	return f_wvdial.exist();
}

static const char STUPIDMODE[]="Stupid Mode";

/*
	Update /etc/wvdial.conf
*/
void wvdial_update (
	const char *config,
	const char *login,
	const char *passwd,
	const char *phone,
	const char *modemport,
	const char *linespeed,
	bool stupidmode)
{
	/* #Specification: /etc/wvdial.conf / conditionnal updates
		The redhatppp module only update the /etc/wvdial.conf if it
		exist.
	*/
	if (f_wvdial.exist()){
		CONFDB conf (f_wvdial,true,';');
		SSTRING subsys;
		subsys.setfromf("Dialer %s",config);
		conf.setcursys (subsys.get(),true);
		conf.replacek ("Modem",modemport);
		conf.replacek ("Baud",linespeed);
		conf.replacek ("Phone",phone);
		conf.replacek ("Username",login);
		conf.replacek ("Password",passwd);
		conf.replacek (STUPIDMODE,stupidmode ? "1" : "0");
		conf.save();
	}
}

/*
	Return the stupidmode setting as stored in wvdial.conf
*/
bool wvdial_getstupidmode(const char *config)
{
	bool ret = false;
	if (f_wvdial.exist()){
		CONFDB conf (f_wvdial,true,';');
		SSTRING subsys;
		subsys.setfromf("Dialer %s",config);
		conf.setcursys (subsys.get(),true);
		const char *val = conf.getvalk (STUPIDMODE,"0");
		if (strcmp(val,"1")==0
			|| strcmp(val,"true")==0) ret = true;
	}
	return ret;
}
